@@ -2,6 +2,9 @@
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
+
+from __future__ import annotations
+
 import argparse
 import copy
 import glob
@@ -10,28 +13,30 @@ import logging
 import os
 import sys
 from pathlib import Path
-from typing import Dict
+from typing import Any, Dict, Sequence, TypedDict
 
-import jsonschema
+from typing_extensions import Unpack
 
 import cfnlint.decode.cfn_yaml
-from cfnlint.helpers import REGIONS
+from cfnlint.helpers import REGIONS, format_json_string
+from cfnlint.jsonschema import StandardValidator
 from cfnlint.version import __version__
 
 # pylint: disable=too-many-public-methods
 LOGGER = logging.getLogger("cfnlint")
 
+_DEFAULT_RULESDIR = os.path.join(os.path.dirname(__file__), "rules")
+
 
 def configure_logging(debug_logging, info_logging):
     ch = logging.StreamHandler()
-    ch.setLevel(logging.DEBUG)
 
     if debug_logging:
         LOGGER.setLevel(logging.DEBUG)
     elif info_logging:
         LOGGER.setLevel(logging.INFO)
     else:
-        LOGGER.setLevel(logging.NOTSET)
+        LOGGER.setLevel(logging.WARNING)
     log_formatter = logging.Formatter(
         "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
     )
@@ -46,13 +51,14 @@ def configure_logging(debug_logging, info_logging):
 class ConfigFileArgs:
     """
     Config File arguments.
-    Parses .cfnlintrc OR .cfnlintrc.yaml OR .cfnlintrc.yml in the Home and Project folder.
+    Parses .cfnlintrc OR .cfnlintrc.yaml OR .cfnlintrc.yml
+    in the Home and Project folder.
     """
 
     file_args: Dict = {}
-    __user_config_file = None
-    __project_config_file = None
-    __custom_config_file = None
+    _user_config_file = None
+    _project_config_file = None
+    _custom_config_file = None
 
     def __init__(self, schema=None, config_file=None):
         # self.file_args = self.get_config_file_defaults()
@@ -65,10 +71,10 @@ class ConfigFileArgs:
         self.schema = self.default_schema if not schema else schema
 
         if config_file:
-            self.__custom_config_file = config_file
+            self._custom_config_file = config_file
         else:
             LOGGER.debug("Looking for CFLINTRC before attempting to load")
-            self.__user_config_file, self.__project_config_file = self._find_config()
+            self._user_config_file, self._project_config_file = self._find_config()
 
         self.load()
 
@@ -84,24 +90,28 @@ class ConfigFileArgs:
             > user_config, project_config = self._find_config()
         """
         config_file_name = ".cfnlintrc"
-        self.__user_config_file = Path.home().joinpath(config_file_name)
-
-        self.__project_config_file = Path.cwd().joinpath(config_file_name)
-        if self._has_file(config_file_name + ".yaml"):
-            self.__project_config_file = Path.cwd().joinpath(config_file_name + ".yaml")
-        elif self._has_file(config_file_name + ".yml"):
-            self.__project_config_file = Path.cwd().joinpath(config_file_name + ".yml")
 
         user_config_path = ""
+        home_path = Path.home()
+        for path in [
+            home_path.joinpath(config_file_name),
+            home_path.joinpath(f"{config_file_name}.yaml"),
+            home_path.joinpath(f"{config_file_name}.yml"),
+        ]:
+            if self._has_file(path):
+                user_config_path = path
+                break
+
         project_config_path = ""
-
-        if self._has_file(self.__user_config_file):
-            LOGGER.debug("Found User CFNLINTRC")
-            user_config_path = self.__user_config_file
-
-        if self._has_file(self.__project_config_file):
-            LOGGER.debug("Found Project level CFNLINTRC")
-            project_config_path = self.__project_config_file
+        cwd_path = Path.cwd()
+        for path in [
+            cwd_path.joinpath(config_file_name),
+            cwd_path.joinpath(f"{config_file_name}.yaml"),
+            cwd_path.joinpath(f"{config_file_name}.yml"),
+        ]:
+            if self._has_file(path):
+                project_config_path = path
+                break
 
         return user_config_path, project_config_path
 
@@ -126,8 +136,8 @@ class ConfigFileArgs:
             CFLINTRC configuration
         """
 
-        if self.__custom_config_file:
-            custom_config = self._read_config(self.__custom_config_file)
+        if self._custom_config_file:
+            custom_config = self._read_config(self._custom_config_file)
             LOGGER.debug("Validating Custom CFNLINTRC")
             self.validate_config(custom_config, self.schema)
             LOGGER.debug("Custom configuration loaded as")
@@ -135,11 +145,11 @@ class ConfigFileArgs:
 
             self.file_args = custom_config
         else:
-            user_config = self._read_config(self.__user_config_file)
+            user_config = self._read_config(self._user_config_file)
             LOGGER.debug("Validating User CFNLINTRC")
             self.validate_config(user_config, self.schema)
 
-            project_config = self._read_config(self.__project_config_file)
+            project_config = self._read_config(self._project_config_file)
             LOGGER.debug("Validating Project CFNLINTRC")
             self.validate_config(project_config, self.schema)
 
@@ -168,7 +178,8 @@ class ConfigFileArgs:
         LOGGER.debug("Schema used: %s", schema)
         LOGGER.debug("Config used: %s", config)
 
-        jsonschema.validate(config, schema)
+        validator = StandardValidator(schema=schema)
+        validator.validate(config)
         LOGGER.debug("CFNLINTRC looks valid!")
 
     def merge_config(self, user_config, project_config):
@@ -308,11 +319,9 @@ class RuleConfigurationAction(argparse.Action):
 class CliArgs:
     """Base Args class"""
 
-    cli_args: Dict = {}
-
-    def __init__(self, cli_args):
+    def __init__(self, cli_args: Sequence[str] | None):
         self.parser = self.create_parser()
-        self.cli_args, _ = self.parser.parse_known_args(cli_args)
+        self.cli_args = self.parser.parse_args(cli_args or [])
 
     def create_parser(self):
         """Do first round of parsing parameters to set options"""
@@ -325,7 +334,9 @@ class CliArgs:
                 self.exit(32, f"{self.prog}: error: {message}\n")
 
         class ExtendAction(argparse.Action):
-            """Support argument types that are lists and can be specified multiple times."""
+            """Support argument types that are lists and can
+            be specified multiple times.
+            """
 
             def __call__(self, parser, namespace, values, option_string=None):
                 items = getattr(namespace, self.dest)
@@ -340,7 +351,7 @@ class CliArgs:
         usage = (
             "\nBasic: cfn-lint test.yaml\n"
             "Ignore a rule: cfn-lint -i E3012 -- test.yaml\n"
-            "Configure a rule: cfn-lint -x E3012:strict=false -t test.yaml\n"
+            "Configure a rule: cfn-lint -x E3012:strict=true -t test.yaml\n"
             "Lint all yaml files in a folder: cfn-lint dir/**/*.yaml"
         )
 
@@ -419,8 +430,10 @@ class CliArgs:
             default=[],
             type=comma_separated_arg,
             action="extend",
-            help="specify one or more rules directories using "
-            "one or more --append-rules arguments. ",
+            help=(
+                "specify one or more rules directories using "
+                "one or more --append-rules arguments. "
+            ),
         )
         standard.add_argument(
             "-i",
@@ -450,7 +463,10 @@ class CliArgs:
             default=[],
             type=comma_separated_arg,
             action="extend",
-            help="always check rules whose id match these values, regardless of template exclusions",
+            help=(
+                "always check rules whose id match these values, regardless of template"
+                " exclusions"
+            ),
         )
         standard.add_argument(
             "-e",
@@ -465,7 +481,10 @@ class CliArgs:
             nargs="+",
             default={},
             action=RuleConfigurationAction,
-            help="Provide configuration for a rule. Format RuleId:key=value. Example: E3012:strict=false",
+            help=(
+                "Provide configuration for a rule. Format RuleId:key=value. Example:"
+                " E3012:strict=true"
+            ),
         )
         standard.add_argument(
             "--config-file",
@@ -487,7 +506,10 @@ class CliArgs:
         advanced.add_argument(
             "-g",
             "--build-graph",
-            help="Creates a file in the same directory as the template that models the template's resources in DOT format",
+            help=(
+                "Creates a file in the same directory as the template that models the"
+                " template's resources in DOT format"
+            ),
             action="store_true",
         )
         advanced.add_argument(
@@ -511,6 +533,12 @@ class CliArgs:
             help="Update the CloudFormation Specs",
             action="store_true",
         )
+        advanced.add_argument(
+            "-p",
+            "--patch-specs",
+            help="Patch the CloudFormation Specs in place",
+            action="store_true",
+        )
         advanced.add_argument(
             "--update-documentation", help=argparse.SUPPRESS, action="store_true"
         )
@@ -553,57 +581,80 @@ class TemplateArgs:
     def set_template_args(self, template):
         defaults = {}
         if isinstance(template, dict):
-            metadata = template.get("Metadata", {})
-            if metadata:
-                configs = (
-                    template.get("Metadata", {}).get("cfn-lint", {}).get("config", {})
-                )
+            configs = template.get("Metadata", {}).get("cfn-lint", {}).get("config", {})
 
-                if isinstance(configs, dict):
-                    for config_name, config_value in configs.items():
-                        if config_name == "ignore_checks":
-                            if isinstance(config_value, list):
-                                defaults["ignore_checks"] = config_value
-                        if config_name == "regions":
-                            if isinstance(config_value, list):
-                                defaults["regions"] = config_value
-                        if config_name == "append_rules":
-                            if isinstance(config_value, list):
-                                defaults["append_rules"] = config_value
-                        if config_name == "override_spec":
-                            if isinstance(config_value, (str)):
-                                defaults["override_spec"] = config_value
-                        if config_name == "custom_rules":
-                            if isinstance(config_value, (str)):
-                                defaults["custom_rules"] = config_value
-                        if config_name == "ignore_bad_template":
-                            if isinstance(config_value, bool):
-                                defaults["ignore_bad_template"] = config_value
-                        if config_name == "include_checks":
-                            if isinstance(config_value, list):
-                                defaults["include_checks"] = config_value
-                        if config_name == "configure_rules":
-                            if isinstance(config_value, dict):
-                                defaults["configure_rules"] = config_value
+            if isinstance(configs, dict):
+                for key, value in {
+                    "ignore_checks": (list),
+                    "regions": (list),
+                    "append_rules": (list),
+                    "override_spec": (str),
+                    "custom_rules": (str),
+                    "ignore_bad_template": (bool),
+                    "include_checks": (list),
+                    "configure_rules": (dict),
+                    "include_experimental": (bool),
+                }.items():
+                    if key in configs:
+                        if isinstance(configs[key], value):
+                            defaults[key] = configs[key]
 
         self._template_args = defaults
 
     template_args = property(get_template_args, set_template_args)
 
 
+class ManualArgs(TypedDict, total=False):
+    configure_rules: dict[str, dict[str, Any]]
+    include_checks: list[str]
+    ignore_checks: list[str]
+    mandatory_checks: list[str]
+    include_experimental: bool
+    ignore_bad_template: bool
+    ignore_templates: list
+    merge_configs: bool
+    non_zero_exit_code: str
+    output_file: str
+    regions: list
+
+
 # pylint: disable=too-many-public-methods
 class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
     """Mixin for the Configs"""
 
-    def __init__(self, cli_args):
+    def __init__(self, cli_args: list[str] | None = None, **kwargs: Unpack[ManualArgs]):
+        self._manual_args = kwargs or ManualArgs()
+        self._templates_to_process = False
         CliArgs.__init__(self, cli_args)
         # configure debug as soon as we can
-        configure_logging(self.cli_args.debug, self.cli_args.info)
         TemplateArgs.__init__(self, {})
         ConfigFileArgs.__init__(
             self, config_file=self._get_argument_value("config_file", False, False)
         )
 
+    def __repr__(self):
+        return format_json_string(
+            {
+                "ignore_checks": self.ignore_checks,
+                "include_checks": self.include_checks,
+                "mandatory_checks": self.mandatory_checks,
+                "include_experimental": self.include_experimental,
+                "configure_rules": self.configure_rules,
+                "regions": self.regions,
+                "ignore_bad_template": self.ignore_bad_template,
+                "debug": self.debug,
+                "info": self.info,
+                "format": self.format,
+                "templates": self.templates,
+                "append_rules": self.append_rules,
+                "override_spec": self.override_spec,
+                "custom_rules": self.custom_rules,
+                "config_file": self.config_file,
+                "merge_configs": self.merge_configs,
+                "non_zero_exit_code": self.non_zero_exit_code,
+            }
+        )
+
     def _get_argument_value(self, arg_name, is_template, is_config_file):
         cli_value = getattr(self.cli_args, arg_name)
         template_value = self.template_args.get(arg_name)
@@ -616,8 +667,9 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
                 # the CLI will always have an empty list when the item is a list
                 # we will use that to evaluate if we need to merge the lists
                 if isinstance(cli_value, list):
-                    # Use a copy here, otherwise we will accumulate template level config
-                    # into the cli_value which will  persist between template files
+                    # Use a copy here, otherwise we will
+                    # accumulate template level config
+                    # into the cli_value which will persist between template files
                     result = cli_value.copy()
                     if isinstance(template_value, list):
                         result.extend(template_value)
@@ -626,6 +678,8 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
                     return result
 
         # return individual items
+        if arg_name in self._manual_args:
+            return self._manual_args[arg_name]
         if cli_value:
             return cli_value
         if template_value and is_template:
@@ -669,42 +723,57 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
     def debug(self):
         return self._get_argument_value("debug", False, False)
 
+    @property
+    def info(self):
+        return self._get_argument_value("info", False, False)
+
     @property
     def format(self):
         return self._get_argument_value("format", False, True)
 
     @property
     def templates(self):
-        templates_args = self._get_argument_value("templates", False, True)
-        template_alt_args = self._get_argument_value("template_alt", False, False)
-        if template_alt_args:
-            filenames = template_alt_args
-        elif templates_args:
-            filenames = templates_args
+        """
+
+        Returns a list of Cloudformation templates to lint.
+
+        Order of precedence:
+        - Filenames provided via `-t` CLI
+        - Filenames specified in the config file.
+        - Arguments provided via `cfn-lint` CLI.
+        """
+
+        all_filenames = []
+
+        cli_alt_args = self._get_argument_value("template_alt", False, False)
+        file_args = self._get_argument_value("templates", False, True)
+        cli_args = self._get_argument_value("templates", False, False)
+
+        if cli_alt_args:
+            filenames = cli_alt_args
+        elif file_args:
+            filenames = file_args
+        elif cli_args:
+            filenames = cli_args
         else:
+            # No filenames found, could be piped in or be using the api.
             return None
 
-        # if only one is specified convert it to array
+        # If we're still haven't returned, we've got templates to lint.
+        # Build up list of templates to lint.
+        self.templates_to_process = True
+
         if isinstance(filenames, str):
             filenames = [filenames]
 
-        # handle different shells and Config files
-        # some shells don't expand * and configparser won't expand wildcards
-        all_filenames = []
         ignore_templates = self._ignore_templates()
-        for filename in filenames:
-            add_filenames = glob.glob(filename, recursive=True)
-            # only way to know of the glob failed is to test it
-            # then add the filename as requested
-            if not add_filenames:
-                if filename not in ignore_templates:
-                    all_filenames.append(filename)
-            else:
-                for add_filename in add_filenames:
-                    if add_filename not in ignore_templates:
-                        all_filenames.append(add_filename)
+        all_filenames.extend(self._glob_filenames(filenames))
 
-        return sorted(all_filenames)
+        found_files = [i for i in all_filenames if i not in ignore_templates]
+        LOGGER.debug(
+            f"List of Cloudformation Templates to lint: {found_files} from {filenames}"
+        )
+        return found_files
 
     def _ignore_templates(self):
         ignore_template_args = self._get_argument_value("ignore_templates", False, True)
@@ -717,23 +786,28 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
         if isinstance(filenames, str):
             filenames = [filenames]
 
+        return self._glob_filenames(filenames)
+
+    def _glob_filenames(self, filenames: Sequence[str]) -> list[str]:
         # handle different shells and Config files
         # some shells don't expand * and configparser won't expand wildcards
         all_filenames = []
+
         for filename in filenames:
             add_filenames = glob.glob(filename, recursive=True)
-            # only way to know of the glob failed is to test it
-            # then add the filename as requested
-            if not add_filenames:
-                all_filenames.append(filename)
-            else:
-                all_filenames.extend(add_filenames)
 
-        return all_filenames
+            if not add_filenames and not self.ignore_bad_template:
+                raise ValueError(f"{filename} could not be processed by glob.glob")
+
+            all_filenames.extend(add_filenames)
+
+        return sorted(list(map(str, map(Path, all_filenames))))
 
     @property
     def append_rules(self):
-        return self._get_argument_value("append_rules", False, True)
+        return [_DEFAULT_RULESDIR] + self._get_argument_value(
+            "append_rules", False, True
+        )
 
     @property
     def override_spec(self):
@@ -748,6 +822,10 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
     def update_specs(self):
         return self._get_argument_value("update_specs", False, False)
 
+    @property
+    def patch_specs(self):
+        return self._get_argument_value("patch_specs", False, False)
+
     @property
     def update_documentation(self):
         return self._get_argument_value("update_documentation", False, False)
@@ -791,3 +869,11 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
     @property
     def force(self):
         return self._get_argument_value("force", False, False)
+
+    @property
+    def templates_to_process(self):
+        return self._templates_to_process
+
+    @templates_to_process.setter
+    def templates_to_process(self, value: bool):
+        self._templates_to_process = value
