@@ -56,6 +56,11 @@ AVAILABILITY_ZONES = {
         "ap-southeast-4b",
         "ap-southeast-4c",
     ],
+    "ap-southeast-5": [
+        "ap-southeast-5a",
+        "ap-southeast-5b",
+        "ap-southeast-5c",
+    ],
     "ca-west-1": [
         "ca-west-1a",
         "ca-west-1b",
@@ -180,12 +185,33 @@ FUNCTION_OR = "Fn::Or"
 FUNCTION_NOT = "Fn::Not"
 FUNCTION_EQUALS = "Fn::Equals"
 FUNCTION_BASE64 = "Fn::Base64"
+FUNCTION_CONTAINS = "Fn::Contains"
+FUNCTION_EACH_MEMBER_EQUALS = "Fn::EachMemberEquals"
+FUNCTION_EACH_MEMBER_IN = "Fn::EachMemberIn"
+FUNCTION_REF_ALL = "Fn::RefAll"
+FUNCTION_VALUE_OF = "Fn::ValueOf"
+FUNCTION_VALUE_OF_ALL = "Fn::ValueOfAll"
 FUNCTION_FOR_EACH = re.compile(r"^Fn::ForEach::[a-zA-Z0-9]+$")
 
 FUNCTION_CONDITIONS = frozenset(
     [FUNCTION_AND, FUNCTION_OR, FUNCTION_NOT, FUNCTION_EQUALS]
 )
 
+FUNCTION_RULES = frozenset(
+    [
+        FUNCTION_AND,
+        FUNCTION_OR,
+        FUNCTION_NOT,
+        FUNCTION_EQUALS,
+        FUNCTION_CONTAINS,
+        FUNCTION_EACH_MEMBER_EQUALS,
+        FUNCTION_EACH_MEMBER_IN,
+        FUNCTION_REF_ALL,
+        FUNCTION_VALUE_OF,
+        FUNCTION_VALUE_OF_ALL,
+    ]
+)
+
 FUNCTIONS_ALL = frozenset.union(
     *[FUNCTIONS, FUNCTION_CONDITIONS, frozenset(["Condition"])]
 )
